pub struct ReceiverReportInterceptor { /* private fields */ }Expand description
Interceptor that generates RTCP Receiver Reports.
This interceptor monitors incoming RTP packets, tracks statistics per stream, and periodically generates RTCP Receiver Reports.
Type Parameters
P: The inner protocol being wrapped
Example
use rtc_interceptor::{Slot, Registry, ReceiverReportBuilder};
let chain = Registry::new()
.with(Slot::ReceiverReport, ReceiverReportBuilder::new().build())
.build();Trait Implementations
Sourceimpl Interceptor for ReceiverReportInterceptor
impl Interceptor for ReceiverReportInterceptor
Sourcefn bind_remote_stream(&mut self, info: &StreamInfo)
fn bind_remote_stream(&mut self, info: &StreamInfo)
bind_remote_stream lets you modify any incoming RTP packets. It is called once for per RemoteStream. The returned method
will be called once per rtp packet.
Sourcefn unbind_remote_stream(&mut self, info: &StreamInfo)
fn unbind_remote_stream(&mut self, info: &StreamInfo)
unbind_remote_stream is called when the Stream is removed. It can be used to clean up any data related to that track.
Sourcefn bind_local_stream(&mut self, _info: &StreamInfo)
fn bind_local_stream(&mut self, _info: &StreamInfo)
bind_local_stream lets you modify any outgoing RTP packets. It is called once for per LocalStream. The returned method
will be called once per rtp packet.
Sourcefn unbind_local_stream(&mut self, _info: &StreamInfo)
fn unbind_local_stream(&mut self, _info: &StreamInfo)
unbind_local_stream is called when the Stream is removed. It can be used to clean up any data related to that track.
Sourceimpl Protocol<TransportMessage<AttributedPacket>, TransportMessage<AttributedPacket>, ()> for ReceiverReportInterceptor
impl Protocol<TransportMessage<AttributedPacket>, TransportMessage<AttributedPacket>, ()> for ReceiverReportInterceptor
Sourcetype Rout = TransportMessage<AttributedPacket>
type Rout = TransportMessage<AttributedPacket>
Output read message type Read more
Sourcetype Wout = TransportMessage<AttributedPacket>
type Wout = TransportMessage<AttributedPacket>
Output write message type Read more
Sourcefn handle_read(&mut self, msg: TaggedPacket) -> Result<(), Self::Error>
fn handle_read(&mut self, msg: TaggedPacket) -> Result<(), Self::Error>
Handle an incoming read message. Read more
Sourcefn handle_write(&mut self, msg: TaggedPacket) -> Result<(), Self::Error>
fn handle_write(&mut self, msg: TaggedPacket) -> Result<(), Self::Error>
Handle an outgoing write message. Read more
Sourcefn poll_write(&mut self) -> Option<TaggedPacket>
fn poll_write(&mut self) -> Option<TaggedPacket>
Poll for a processed write message. Read more
Sourcefn handle_timeout(&mut self, now: Instant) -> Result<(), Error>
fn handle_timeout(&mut self, now: Instant) -> Result<(), Error>
Handle a timeout event. Read more