pub struct Report {
pub arrival: Instant,
pub rtt: Option<Duration>,
pub packet_reports: Vec<PacketReport>,
}Expand description
A batch of packet reports, with the round trip time they imply.
Fields
arrival: InstantWhen the feedback that produced this batch was received here.
rtt: Option<Duration>Round trip time derived from the newest packet this feedback acknowledged.
packet_reports: Vec<PacketReport>The packets being reported on, in send order.